%
% This function evaluates GreedyTL model, under assumption that labels are binary and in {-1,1}.
%
% eval_greedytl(weights, x, source_pred, y);
%
% Input:
% x -- m-by-d matrix of testing examples, where m is number of examples and d is the dimension.
% source_pred -- n-by-d matrix of source hypothesis predictions on testing examples, where n is number of source hypotheses.
% y -- vector of testing labels of size m. Each label is in {-1, 1}.
%
% Output:
% acc -- prediction accuracy.
% bal_acc -- class-balanced prediction accuracy.
%
% Contact the author: ilja.kuzborskij [at] idiap.ch
%                     http:%idiap.ch/~ikuzbor
%
% ----------------------------------------------------------------------------------
%
% Copyright (c) 2014 Idiap Research Institute, http:%www.idiap.ch/
% Written by Ilja Kuzborskij <ilja.kuzborskij@idiap.ch>
%
% This file is part of GreedyTL.
%
% GreedyTL is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License version 3 as
% published by the Free Software Foundation.
%
% GreedyTL is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with GreedyTL. If not, see <http:%www.gnu.org/licenses/>.
%

function [acc, bal_acc] = eval_greedytl(weights, x, source_pred, y)
    joint_test_x = [source_pred x];
    joint_test_x = standardize_cols(joint_test_x);
    y = standardize_cols(y);
    y = sign(y);

    pred = sign(joint_test_x * weights);
    acc = mean(pred == y);

    if any(y==1) && any(y==-1)
        bal_acc = 0.5 * mean( pred(y==1) == y(y==1) ) + ...
                  0.5 * mean( pred(y==-1) == y(y==-1) );
    else
        bal_acc = mean(pred == y);
    end
end

