//
// This function performs Tikhonov (L2) regularized forward regression.
//
// train_fr_tikhonov(mat X, vec y, double errtol, double lambda);
//
// Input:
// X -- m-by-d (Eigen) matrix of training examples, where m is number of examples and d is the dimension.
// y -- vector of training labels of size m.
// errtol -- greedy selection stopping threshold.
// lambda -- Tikhonov regularization parameter.

//
// Output:
// w -- weight vector of dimension d.
//
// Contact the author: ilja.kuzborskij [at] idiap.ch
//                     http://idiap.ch/~ikuzbor
//
// ----------------------------------------------------------------------------------
//
// Copyright (c) 2014 Idiap Research Institute, http://www.idiap.ch/
// Written by Ilja Kuzborskij <ilja.kuzborskij@idiap.ch>
//
// This file is part of GreedyTL.
//
// GreedyTL is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 3 as
// published by the Free Software Foundation.
//
// GreedyTL is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GreedyTL. If not, see <http://www.gnu.org/licenses/>.
//

#ifndef TRAIN_FR_TIKHONOV_HPP
#define TRAIN_FR_TIKHONOV_HPP

#include <string.h>
#include <limits>
#include <Eigen/Core>
#include <Eigen/Dense>

using namespace std;

typedef Eigen::MatrixXd mat;
typedef Eigen::VectorXd vec;

vec train_fr_tikhonov(mat X, vec y, double errtol, double lambda);

#endif
