%
% This function trains GreedyTL model.
%
% train_greedytl(hp, x, source_pred, y);
%
% Input:
% hp.lambda -- Tikhonov regularization parameter.
% x -- m-by-d matrix of training examples, where m is number of examples and d is the dimension.
% source_pred -- n-by-d matrix of source hypothesis predictions on training examples, where n is number of source hypotheses.
% y -- vector of training labels of size m.
%
% Output:
% w -- weight vector of dimension d+n.
%
% Contact the author: ilja.kuzborskij [at] idiap.ch
%                     http:%idiap.ch/~ikuzbor
%
% ----------------------------------------------------------------------------------
%
% Copyright (c) 2014 Idiap Research Institute, http:%www.idiap.ch/
% Written by Ilja Kuzborskij <ilja.kuzborskij@idiap.ch>
%
% This file is part of GreedyTL.
%
% GreedyTL is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License version 3 as
% published by the Free Software Foundation.
%
% GreedyTL is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with GreedyTL. If not, see <http:%www.gnu.org/licenses/>.
%

function weights = train_greedytl(hp, x, source_pred, y)
    joint_train_x = [source_pred x];
    joint_train_x = standardize_cols(joint_train_x);
    y = standardize_cols(y);

    weights = train_fr_tikhonov_mex(hp, joint_train_x, y);
end
